@@ -1,5 +1,6 @@
-from datetime import datetime, timedelta
+from datetime import timedelta
 
+from django.utils.timezone import now as tznow
 from django.template.loader import render_to_string
 
 from nano.blog.models import Entry as _Entry
@@ -19,7 +20,7 @@ def add_entry_to_blog(obj, headline, template, date_field='last_modified'):
     date_field: date_field on object to be used for publishing date
     """
     data = {'obj': obj}
-    current_time = datetime.now()
+    current_time = tznow()
     template = render_to_string(template, dictionary=data)
     pub_date = obj.__dict__.get(date_field, current_time)
     latest = _Entry.objects.latest()
