@@ -1,5 +1,4 @@
-
-from django.conf.urls.defaults import *
+from django.conf.urls import *
 
 from nano.badge.models import *
 
